@@ -130,4 +130,4 @@ def showGraph():
     nx.draw(g, with_labels=True, labels=names)
     fig = plt.gcf()
     fig.set_size_inches(20, 15)
-    fig.savefig('artifacts/graph.pdf')
+    fig.savefig('artifacts/graph.png')
